﻿// 
// Copyright (c) 2013-2016 Carsten Sonne Larsen <cs@innolan.dk>
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.IO;
using System.Linq;

namespace Ntp.Common.IO
{
    public static class DirectoryCommand
    {
        public static string CreateRecursive(string path)
        {
            string fullPath = path.Trim();
            if (fullPath.Length <= 1)
                return null;

            string created = null;
            char[] s = {'/'};
            var elements = fullPath.Split(s, StringSplitOptions.RemoveEmptyEntries).ToList();

            string currentPath = string.Empty;
            foreach (string element in elements)
            {
                currentPath = $"{currentPath}/{element}";
                if (Directory.Exists(currentPath))
                    continue;

                Directory.CreateDirectory(currentPath);
                created = currentPath;
            }

            return created;
        }

        public static string CreateRecursiveFromFile(string file)
        {
            int pos = file.LastIndexOf('/');
            if (pos == -1)
                return null;

            string path = file.Substring(0, pos);
            return CreateRecursive(path);
        }
    }
}